Flask-Annex |Travis| |PyPI|
===========================

Efficient integration of external storage services for
`Flask <http://flask.pocoo.org/>`__.

|Codecov|

.. |Travis| image:: https://img.shields.io/travis/4Catalyzer/flask-annex/master.svg
   :target: https://travis-ci.org/4Catalyzer/flask-annex
.. |PyPI| image:: https://img.shields.io/pypi/v/Flask-Annex.svg
   :target: https://pypi.python.org/pypi/Flask-Annex
.. |Codecov| image:: https://img.shields.io/codecov/c/github/4Catalyzer/flask-annex/master.svg
   :target: https://codecov.io/gh/4Catalyzer/flask-annex
